@@ -29,8 +29,6 @@ __license__   = "LGPL"
 
 import os
 
-screenWidth = 640
-screenHeight = 480
 tty = 7
 
 # Whether tool tips can be presented.
@@ -408,161 +406,6 @@ enableBrailleMonitor    = False
 #
 enableMagnifier                  = False
 
-# If True, show the magnification cursor.
-#
-enableMagCursor                  = True
-
-# If True, allow an explicit size for the magnification cursor.
-#
-enableMagCursorExplicitSize      = False
-
-# If True, hide the system cursor.
-#
-magHideCursor                    = False
-
-# Size of the magnification cursor (in pixels).
-#
-magCursorSize                    = 32
-
-# Magnification cursor color value (hex color spec).
-#
-magCursorColor                   = '#000000'
-
-# If True, show the magnification cross-hairs.
-#
-enableMagCrossHair               = True
-
-# If True, enable magnification cross-hair clipping.
-#
-enableMagCrossHairClip           = False
-
-# Size of the magnification cross-hairs (in pixels).
-#
-magCrossHairSize                 = 16
-
-# Magnification cross-hair color value (hex color spec).
-#
-magCrossHairColor                   = '#000000'
-
-# Magnification Zoomer type.
-#
-MAG_ZOOMER_TYPE_FULL_SCREEN      = 0
-MAG_ZOOMER_TYPE_TOP_HALF         = 1
-MAG_ZOOMER_TYPE_BOTTOM_HALF      = 2
-MAG_ZOOMER_TYPE_LEFT_HALF        = 3
-MAG_ZOOMER_TYPE_RIGHT_HALF       = 4
-MAG_ZOOMER_TYPE_CUSTOM           = 5
-magZoomerType                    = MAG_ZOOMER_TYPE_FULL_SCREEN
-
-# Magnification zoomer region placement.
-#
-magZoomerLeft                    = screenWidth / 2
-magZoomerRight                   = screenWidth
-magZoomerTop                     = 0
-magZoomerBottom                  = screenHeight
-
-# Magnification zoom factor.
-#
-magZoomFactor                    = 4.0
-
-# If True, display a border around the magnification zoomer region.
-#
-enableMagZoomerBorder           = False
-
-# The color and size of the border which separates the target
-# display from the source display.
-#
-magZoomerBorderSize              = 1
-magZoomerBorderColor             = '#000000'
-
-# If True, invert the magnification zoomer colors.
-#
-enableMagZoomerColorInversion    = False
-
-# The brightness levels.  The range is from -1 to 1, with 0
-# being "normal"/no change.
-#
-magBrightnessLevel               = 0
-magBrightnessLevelRed            = 0
-magBrightnessLevelGreen          = 0
-magBrightnessLevelBlue           = 0
-
-# The contrast levels.  The range is from -1 to 1, with 0
-# being "normal"/no change.
-#
-magContrastLevel                 = 0
-magContrastLevelRed              = 0
-magContrastLevelGreen            = 0
-magContrastLevelBlue             = 0
-
-# Magnification libcolorblind color filtering mode (see magColorFilteringMode).
-#
-MAG_COLOR_FILTERING_MODE_NONE                 = 0
-MAG_COLOR_FILTERING_MODE_SATURATE_RED         = 1
-MAG_COLOR_FILTERING_MODE_SATURATE_GREEN       = 2
-MAG_COLOR_FILTERING_MODE_SATURATE_BLUE        = 3
-MAG_COLOR_FILTERING_MODE_DESATURATE_RED       = 4
-MAG_COLOR_FILTERING_MODE_DESATURATE_GREEN     = 5
-MAG_COLOR_FILTERING_MODE_DESATURATE_BLUE      = 6
-MAG_COLOR_FILTERING_MODE_POSITIVE_HUE_SHIFT   = 7
-MAG_COLOR_FILTERING_MODE_NEGATIVE_HUE_SHIFT   = 8
-magColorFilteringMode = MAG_COLOR_FILTERING_MODE_NONE
-
-# Magnification smoothing mode (see magSmoothingMode).
-#
-MAG_SMOOTHING_MODE_BILINEAR      = 0
-MAG_SMOOTHING_MODE_NONE          = 1
-magSmoothingMode                 = MAG_SMOOTHING_MODE_BILINEAR
-
-# Magnification tracking mode styles (see magMouseTrackingMode,
-# magControlTrackingMode and magTextTrackingMode).
-#
-MAG_TRACKING_MODE_CENTERED     = 0
-MAG_TRACKING_MODE_PROPORTIONAL = 1
-MAG_TRACKING_MODE_PUSH         = 2
-MAG_TRACKING_MODE_NONE         = 3
-
-# To retain backward compatibility with previous versions of Orca.
-#
-MAG_MOUSE_TRACKING_MODE_CENTERED = MAG_TRACKING_MODE_CENTERED
-MAG_MOUSE_TRACKING_MODE_PROPORTIONAL = MAG_TRACKING_MODE_PROPORTIONAL
-MAG_MOUSE_TRACKING_MODE_PUSH = MAG_TRACKING_MODE_PUSH
-MAG_MOUSE_TRACKING_MODE_NONE = MAG_TRACKING_MODE_NONE
-
-# Magnification mouse tracking mode.
-#
-magMouseTrackingMode           = MAG_TRACKING_MODE_CENTERED
-
-# Magnification control and menu item tracking mode.
-#
-magControlTrackingMode         = MAG_TRACKING_MODE_PUSH
-
-# Magnification text cursor tracking mode.
-#
-magTextTrackingMode            = MAG_TRACKING_MODE_PUSH
-
-# Magnification edge margin (percentage of screen).
-#
-magEdgeMargin                  = 0
-
-# If enabled, automatically repositions the mouse pointer to the
-# menu item or control with focus.
-#
-magPointerFollowsFocus         = False
-
-# If enabled, automatically repositions the mouse pointer into the
-# zoomer if it's not visible when initially moved.
-#
-magPointerFollowsZoomer        = True
-
-# Magnification source display
-#
-magSourceDisplay                 = ':0.0'
-
-# Magnification target display
-#
-magTargetDisplay                 = ':0.0'
-
 # if True, enable character echo.
 # Note that it is allowable for both enableEchoByCharacter and enableKeyEcho
 # to be True
